@@ -52,6 +52,7 @@ describe 'barbican::api' do
         :kombu_ssl_version                             => '<SERVICE DEFAULT>',
         :kombu_reconnect_delay                         => '<SERVICE DEFAULT>',
         :kombu_failover_strategy                       => '<SERVICE DEFAULT>',
+        :kombu_compression                             => '<SERVICE DEFAULT>',
         :manage_service                                => true,
         :enabled                                       => true,
         :enabled_secretstore_plugins                   => ['<SERVICE DEFAULT>'],
@@ -59,17 +60,19 @@ describe 'barbican::api' do
         :enabled_certificate_plugins                   => ['<SERVICE DEFAULT>'],
         :enabled_certificate_event_plugins             => ['<SERVICE DEFAULT>'],
         :auth_strategy                                 => 'keystone',
-        :retry_scheduler_initial_delay_seconds         => '<SERVICE DEFAULT>',
-        :retry_scheduler_periodic_interval_max_seconds => '<SERVICE DEFAULT>',
         :service_name                                  => platform_params[:service_name],
         :enable_proxy_headers_parsing                  => '<SERVICE DEFAULT>',
         :max_request_body_size                         => '<SERVICE DEFAULT>',
+        :max_limit_paging                              => '<SERVICE DEFAULT>',
+        :default_limit_paging                          => '<SERVICE DEFAULT>',
         :multiple_secret_stores_enabled                => false,
         :enabled_secret_stores                         => 'simple_crypto',
       }
     end
 
-    [{
+    [
+      {},
+      {
         :bind_host                                     => '127.0.0.1',
         :bind_port                                     => '9312',
         :default_transport_url                         => 'rabbit://bugs:bugs_bunny@localhost:1234/rabbithost',
@@ -97,16 +100,17 @@ describe 'barbican::api' do
         :kombu_ssl_version                             => '1.2',
         :kombu_reconnect_delay                         => '10',
         :kombu_failover_strategy                       => 'shuffle',
+        :kombu_compression                             => 'gzip',
         :enabled_secretstore_plugins                   => ['dogtag_crypto', 'store_crypto', 'kmip'],
         :enabled_crypto_plugins                        => ['simple_crypto'],
         :enabled_certificate_plugins                   => ['simple_certificate', 'dogtag'],
         :enabled_certificate_event_plugins             => ['simple_certificate_event', 'foo_event'],
-        :retry_scheduler_initial_delay_seconds         => 20.0,
-        :retry_scheduler_periodic_interval_max_seconds => 20.0,
         :max_allowed_secret_in_bytes                   => 20000,
         :max_allowed_request_size_in_bytes             => 2000000,
         :enable_proxy_headers_parsing                  => false,
         :max_request_body_size                         => '102400',
+        :max_limit_paging                              => 100,
+        :default_limit_paging                          => 10,
         :multiple_secret_stores_enabled                => true,
         :enabled_secret_stores                         => 'simple_crypto,dogtag,kmip',
       }
@@ -157,27 +161,31 @@ describe 'barbican::api' do
         end
 
         it 'configures rabbit' do
-          is_expected.to contain_barbican_config('DEFAULT/transport_url').with_value(param_hash[:default_transport_url])
-          is_expected.to contain_barbican_config('DEFAULT/rpc_response_timeout').with_value(param_hash[:rpc_response_timeout])
-          is_expected.to contain_barbican_config('DEFAULT/control_exchange').with_value(param_hash[:control_exchange])
-          is_expected.to contain_barbican_config('oslo_messaging_notifications/transport_url').with_value(param_hash[:notification_transport_url])
-          is_expected.to contain_barbican_config('oslo_messaging_notifications/driver').with_value(param_hash[:notification_driver])
-          is_expected.to contain_barbican_config('oslo_messaging_notifications/topics').with_value(param_hash[:notification_topics])
-          is_expected.to contain_barbican_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value(param_hash[:rabbit_heartbeat_timeout_threshold])
-          is_expected.to contain_barbican_config('oslo_messaging_rabbit/heartbeat_rate').with_value(param_hash[:rabbit_heartbeat_rate])
-          is_expected.to contain_barbican_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value(param_hash[:rabbit_heartbeat_in_pthread])
+          is_expected.to contain_oslo__messaging__default('barbican_config').with(
+            :transport_url        => param_hash[:default_transport_url],
+            :rpc_response_timeout => param_hash[:rpc_response_timeout],
+            :control_exchange     => param_hash[:control_exchange]
+          )
+          is_expected.to contain_oslo__messaging__notifications('barbican_config').with(
+            :transport_url => param_hash[:notification_transport_url],
+            :driver        => param_hash[:notification_driver],
+            :topics        => param_hash[:notification_topics]
+          )
           is_expected.to contain_oslo__messaging__rabbit('barbican_config').with(
-            :rabbit_use_ssl     => true,
-            :kombu_ssl_ca_certs => 'path_to_certs',
-            :kombu_ssl_certfile => 'path_to_certfile',
-            :kombu_ssl_keyfile  => 'path_to_keyfile',
-            :kombu_ssl_version  => '1.2',
+            :rabbit_use_ssl              => param_hash[:rabbit_use_ssl],
+            :heartbeat_timeout_threshold => param_hash[:rabbit_heartbeat_timeout_threshold],
+            :heartbeat_rate              => param_hash[:rabbit_heartbeat_rate],
+            :heartbeat_in_pthread        => param_hash[:rabbit_heartbeat_in_pthread],
+            :kombu_reconnect_delay       => param_hash[:kombu_reconnect_delay],
+            :kombu_failover_strategy     => param_hash[:kombu_failover_strategy],
+            :amqp_durable_queues         => param_hash[:amqp_durable_queues],
+            :kombu_compression           => param_hash[:kombu_compression],
+            :kombu_ssl_ca_certs          => param_hash[:kombu_ssl_ca_certs],
+            :kombu_ssl_certfile          => param_hash[:kombu_ssl_certfile],
+            :kombu_ssl_keyfile           => param_hash[:kombu_ssl_keyfile],
+            :kombu_ssl_version           => param_hash[:kombu_ssl_version],
+            :rabbit_ha_queues            => param_hash[:rabbit_ha_queues],
           )
-        end
-
-        it 'configures kombu params' do
-          is_expected.to contain_barbican_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value(param_hash[:kombu_reconnect_delay])
-          is_expected.to contain_barbican_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value(param_hash[:kombu_failover_strategy])
         end
 
         it 'configures enabled plugins' do
@@ -197,6 +205,11 @@ describe 'barbican::api' do
           is_expected.to contain_barbican_config('secretstore/enable_multiple_secret_stores') \
             .with_value(param_hash[:multiple_secret_stores_enabled])
         end
+
+        it 'resets the barbican_api pipeline' do
+          is_expected.to contain_barbican_api_paste_ini('pipeline:barbican_api/pipeline')\
+            .with_value('cors http_proxy_to_wsgi unauthenticated-context apiapp')
+        end
       end
     end
 
@@ -232,8 +245,8 @@ describe 'barbican::api' do
 
     describe 'with SSL socket options set' do
       let :pre_condition do
-          'class { "barbican::keystone::authtoken": password => "secret", }
-           include apache'
+        'class { "barbican::keystone::authtoken": password => "secret", }
+         include apache'
       end
 
       let :params do
@@ -252,8 +265,8 @@ describe 'barbican::api' do
 
     describe 'with SSL socket options left by default' do
       let :pre_condition do
-          'class { "barbican::keystone::authtoken": password => "secret", }
-           include apache'
+        'class { "barbican::keystone::authtoken": password => "secret", }
+         include apache'
       end
 
       let :params do
@@ -269,8 +282,8 @@ describe 'barbican::api' do
 
     describe 'with SSL socket options set wrongly configured' do
       let :pre_condition do
-          'class { "barbican::keystone::authtoken": password => "secret", }
-           include apache'
+        'class { "barbican::keystone::authtoken": password => "secret", }
+         include apache'
       end
 
       let :params do
@@ -286,8 +299,8 @@ describe 'barbican::api' do
 
     describe 'with keystone auth' do
       let :pre_condition do
-          'class { "barbican::keystone::authtoken": password => "secret", }
-           include apache'
+        'class { "barbican::keystone::authtoken": password => "secret", }
+         include apache'
       end
 
       let :params do
@@ -297,8 +310,6 @@ describe 'barbican::api' do
       end
 
       it 'is_expected.to set keystone params correctly' do
-        is_expected.to contain_barbican_api_paste_ini('pipeline:barbican_api/pipeline')\
-          .with_value('cors authtoken context apiapp')
         is_expected.to contain_class('barbican::keystone::authtoken')
       end
     end
@@ -332,17 +343,10 @@ describe 'barbican::api' do
           {
             :manage_service => false,
             :enabled        => false,
-            :auth_strategy  => 'keystone',
           }
         end
 
-        it { is_expected.to contain_service('barbican-api').with(
-          'ensure'     => nil,
-          'enable'     => false,
-          'hasstatus'  => true,
-          'hasrestart' => true,
-          'tag'        => 'barbican-service',
-        )}
+        it { is_expected.to_not contain_service('barbican-api') }
       end
     end
   end
@@ -366,9 +370,6 @@ describe 'barbican::api' do
         end
         it_behaves_like 'barbican api redhat'
       when 'Debian'
-        let :pre_condition do
-          'include apache'
-        end
         let (:platform_params) do
           { :service_name => 'httpd' }
         end
